==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterLineSeries = /*@__PURE__*/ (() => {
    class ScatterLineSeries extends ScatterBase {
        get_ex() {
            return true;
        }
        constructor() {
            super();
            this.ab = ScatterLineSeries.$;
            this.v0 = new ScatterFrame();
            this.v2 = new ScatterFrame();
            this.vy = new ScatterFrame();
            let a = (b, c, d) => {
                let e = this.c6.indexOf(b.a);
                if (e == -1 || e == 0) {
                    return b;
                }
                let f = this.c6.item(e - 1);
                let g;
                if (!((() => { let h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                    return b;
                }
                return g;
            };
            this.v0.o = a;
            this.v2.o = a;
            this.vy.o = a;
        }
        cg() {
            return new ScatterLineSeriesView(this);
        }
        wp() {
            return true;
        }
        ip() {
            if (!isNaN_(this.io)) {
                return super.ip();
            }
            return Defaults.x;
        }
        f4(a, b) {
            if (this.ud(a, b)) {
                return true;
            }
            if (this.zf(a, b)) {
                return true;
            }
            return false;
        }
        zf(a, b) {
            let c = this.cj;
            let d = c.dj;
            return this.f5(a, b, d.an);
        }
        x6(a, b) {
            super.x6(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.hj * this.hj;
            let g = 0;
            if (this.wa != null) {
                g = this.wa.count;
            }
            if (this.wb != null) {
                g = Math.min(this.wb.count, g);
            }
            let h = new ScalerParams(0, c, d, this.vu.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.vu.e, e);
                $ret.b = this.h2();
                return $ret;
            })());
            let j = arrayShallowClone(this.wa.asArray());
            let k = arrayShallowClone(this.wb.asArray());
            this.xAxis.hn(boxArray$1(j), 0, j.length, h);
            this.yAxis.hn(boxArray$1(k), 0, k.length, i);
            let l = d.top - 10;
            let m = d.bottom + 10;
            let n = d.left - 10;
            let o = d.right + 10;
            let p = ((() => {
                let $ret = new Clipper(1, n, m, o, l, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let q = 0; q < g;) {
                let r = q;
                ++q;
                if (g > this.w1) {
                    while (q < g) {
                        let s = j[q] - j[r];
                        let t = k[q] - k[r];
                        let u = s * s + t * t;
                        if (u >= f) {
                            break;
                        }
                        ++q;
                    }
                    p.j(this.zm(j, k, r, q - 1));
                }
                else {
                    let v = new OwnedPoint();
                    v.c = { $type: Point_$type, x: j[r], y: k[r] };
                    v.a = this.c6.item(r);
                    if (!a.u.containsKey(v.a)) {
                        a.u.addItem(v.a, v);
                    }
                }
            }
            if (g > this.w1) {
                p.i = null;
            }
        }
        zm(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a[c], y: b[c] };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a[h];
                f += b[h];
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        get_wj() {
            return true;
        }
        yh(a, b) {
            b.c7(false);
            super.yh(a, b);
            let c = this.getEffectiveViewport1(b);
            let d = new Rect(0, b.bx.left, b.bx.top, b.bx.width, b.bx.height);
            d = RectUtil.t(d, this.hk, this.hk);
            this.ya(a, new Clipper(0, d, false));
            let e = typeCast(ScatterLineSeriesView.$, b);
            this.v7.az(this, this.wo(), runOn(this, this.vi));
            let f = false;
            let g = this.v7.b;
            if (g != null) {
                f = true;
            }
            if (f) {
                this.x2(-1, this.wa.count, b.q);
            }
            this.v7.ad(e.dj, true, false, true, false);
            this.zk(e.dj, a.m.count, (h) => a.m._inner[h].x, (h) => a.m._inner[h].y, this.ze, this.hj);
        }
        zk(a, b, c, d, e, f) {
            let g = new PathGeometry();
            a.an = g;
            g.c = new PathFigureCollection();
            let h = new List$1(PolyLineSegment.$, 0);
            let i = 0;
            for (let j = 0; j < b; j++) {
                if (isNaN_(c(j)) || isNaN_(d(j))) {
                    let k = j - i;
                    if (k > 0) {
                        if (e == 1 || h.count == 0) {
                            let l = new PolyLineSegment();
                            h.add(l);
                        }
                        this.zj(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                    }
                    i = j + 1;
                }
            }
            if (e == 1 || h.count == 0) {
                let m = new PolyLineSegment();
                h.add(m);
            }
            this.zj(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
            for (let n = 0; n < h.count; n++) {
                let o = h._inner[n];
                if (o._points.count > 0) {
                    let p = ((() => {
                        let $ret = new PathFigure();
                        $ret.startPoint = o._points._inner[0];
                        return $ret;
                    })());
                    p._segments.add(o);
                    g.c.add(p);
                }
            }
        }
        zg(a, b, c, d, e, f) {
            let g = new List$1(Number_$type, 0);
            let h = d;
            let i = e;
            let j = i - h + 1;
            while (j > 0) {
                if (j <= 512) {
                    Flattener.c(g, b, c, h, i, f);
                    h = i + 1;
                }
                else {
                    let k = h + 512 - 1;
                    Flattener.c(g, b, c, h, k, f);
                    h = k + 1;
                }
                j = i - h + 1;
            }
            return g;
        }
        zj(a, b, c, d, e, f) {
            if (c > -1) {
                let g = !isNaN_(this.io) ? f : 1;
                let h = this.zg(new List$1(Number_$type, 0), d, e, b, c, g);
                let i;
                for (let j = 0; j < h.count; j++) {
                    i = h.item(j);
                    a.add({ $type: Point_$type, x: d(i), y: e(i) });
                }
            }
        }
        o8(a, b, c, d) {
            super.o8(a, b, c, d);
            switch (b) {
                case ScatterLineSeries.$$p[0]:
                    this.pp(false);
                    this.ol();
                    break;
            }
        }
    }
    ScatterLineSeries.$t = /*@__PURE__*/ markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:ze:zl', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterLineSeries = /*@__PURE__*/ (() => {
    class ScatterLineSeries extends ScatterBase {
        bj() {
            return new ScatterLineSeries();
        }
        get_fj() {
            return true;
        }
        constructor() {
            super();
            this.ab = ScatterLineSeries.$;
            this.yx = new ScatterFrame();
            this.yz = new ScatterFrame();
            this.yv = new ScatterFrame();
            let a = (b, c, d) => {
                let e = this.dm.indexOf(b.a);
                if (e == -1 || e == 0) {
                    return b;
                }
                let f = this.dm.item(e - 1);
                let g;
                if (!((() => { let h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                    return b;
                }
                return g;
            };
            this.yx.o = a;
            this.yz.o = a;
            this.yv.o = a;
        }
        cr() {
            return new ScatterLineSeriesView(this);
        }
        zr() {
            return true;
        }
        jj() {
            if (!isNaN_(this.ji)) {
                return super.jj();
            }
            return Defaults.x;
        }
        gv(a, b) {
            if (this.xc(a, b)) {
                return true;
            }
            if (this.acj(a, b)) {
                return true;
            }
            return false;
        }
        acj(a, b) {
            let c = this.cu;
            let d = c.dl;
            return this.gw(a, b, d.an);
        }
        aba(a, b) {
            super.aba(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.ic * this.ic;
            let g = 0;
            if (this.zc != null) {
                g = this.zc.count;
            }
            if (this.zd != null) {
                g = Math.min(this.zd.count, g);
            }
            let h = new ScalerParams(0, c, d, this.yr.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.yr.e, e);
                $ret.b = this.ix();
                return $ret;
            })());
            let j = arrayShallowClone(this.zc.asArray());
            let k = arrayShallowClone(this.zd.asArray());
            this.xAxis.ho(boxArray$1(j), 0, j.length, h);
            this.yAxis.ho(boxArray$1(k), 0, k.length, i);
            let l = d.top - 10;
            let m = d.bottom + 10;
            let n = d.left - 10;
            let o = d.right + 10;
            let p = ((() => {
                let $ret = new Clipper(1, n, m, o, l, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let q = 0; q < g;) {
                let r = q;
                ++q;
                if (g > this.z4) {
                    while (q < g) {
                        let s = j[q] - j[r];
                        let t = k[q] - k[r];
                        let u = s * s + t * t;
                        if (isNaN_(u) || u >= f) {
                            break;
                        }
                        ++q;
                    }
                    p.j(this.acq(j, k, r, q - 1));
                }
                else {
                    let v = new OwnedPoint();
                    v.c = { $type: Point_$type, x: j[r], y: k[r] };
                    v.a = this.dm.item(r);
                    if (!a.u.containsKey(v.a)) {
                        a.u.addItem(v.a, v);
                    }
                }
            }
            if (g > this.z4) {
                p.i = null;
            }
        }
        acq(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a[c], y: b[c] };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a[h];
                f += b[h];
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        get_zl() {
            return true;
        }
        abl(a, b) {
            b.c9(false);
            super.abl(a, b);
            let c = this.getEffectiveViewport1(b);
            let d = new Rect(0, b.bx.left, b.bx.top, b.bx.width, b.bx.height);
            d = RectUtil.t(d, this.id, this.id);
            this.abe(a, new Clipper(0, d, false));
            let e = typeCast(ScatterLineSeriesView.$, b);
            this.y4.az(this, this.zq(), runOn(this, this.yk));
            let f = false;
            let g = this.y4.b;
            if (g != null) {
                f = true;
            }
            if (f) {
                this.aa6(-1, this.zc.count, b.q);
            }
            this.y4.ad(e.dl, true, false, true, false);
            this.aco(e.dl, a.m.count, (h) => a.m._inner[h].x, (h) => a.m._inner[h].y, this.aci, this.ic);
        }
        aco(a, b, c, d, e, f) {
            let g = new PathGeometry();
            a.an = g;
            g.c = new PathFigureCollection();
            let h = new List$1(PolyLineSegment.$, 0);
            let i = 0;
            for (let j = 0; j < b; j++) {
                if (isNaN_(c(j)) || isNaN_(d(j))) {
                    let k = j - i;
                    if (k > 0) {
                        if (e == 1 || h.count == 0) {
                            let l = new PolyLineSegment();
                            h.add(l);
                        }
                        this.acn(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                    }
                    i = j + 1;
                }
            }
            if (e == 1 || h.count == 0) {
                let m = new PolyLineSegment();
                h.add(m);
            }
            this.acn(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
            for (let n = 0; n < h.count; n++) {
                let o = h._inner[n];
                if (o._points.count > 0) {
                    let p = ((() => {
                        let $ret = new PathFigure();
                        $ret.startPoint = o._points._inner[0];
                        return $ret;
                    })());
                    p._segments.add(o);
                    g.c.add(p);
                }
            }
        }
        ack(a, b, c, d, e, f) {
            let g = new List$1(Number_$type, 0);
            let h = d;
            let i = e;
            let j = i - h + 1;
            while (j > 0) {
                if (j <= 512) {
                    Flattener.c(g, b, c, h, i, f);
                    h = i + 1;
                }
                else {
                    let k = h + 512 - 1;
                    Flattener.c(g, b, c, h, k, f);
                    h = k + 1;
                }
                j = i - h + 1;
            }
            return g;
        }
        acn(a, b, c, d, e, f) {
            if (c > -1) {
                let g = !isNaN_(this.ji) ? f : 1;
                let h = this.ack(new List$1(Number_$type, 0), d, e, b, c, g);
                let i;
                for (let j = 0; j < h.count; j++) {
                    i = h.item(j);
                    a.add({ $type: Point_$type, x: d(i), y: e(i) });
                }
            }
        }
        q7(a, b, c, d) {
            super.q7(a, b, c, d);
            switch (b) {
                case ScatterLineSeries.$$p[0]:
                    this.rp(false);
                    this.qj();
                    break;
            }
        }
    }
    ScatterLineSeries.$t = /*@__PURE__*/ markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:aci:acp', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
})();
